Package: GEOmetadb
Type: Package
Title: A compilation of metadata from NCBI GEO
Version: 1.73.0
Date: 2024-12-03
Depends: R.utils,RSQLite
Suggests: knitr, rmarkdown, dplyr, dbplyr, tm, wordcloud
Author: Jack Zhu and Sean Davis
Maintainer: Jack Zhu <zhujack@mail.nih.gov>
biocViews: Infrastructure
Description: The NCBI Gene Expression Omnibus (GEO) represents the largest public repository of microarray data. However, finding data of interest can be challenging using current tools. GEOmetadb is an attempt to make access to the metadata associated with samples, platforms, and datasets much more feasible. This is accomplished by parsing all the NCBI GEO metadata into a SQLite database that can be stored and queried locally. GEOmetadb is simply a thin wrapper around the SQLite database along with associated documentation. Finally, the SQLite database is updated regularly as new data is added to GEO and can be downloaded at will for the most up-to-date metadata. GEOmetadb paper: http://bioinformatics.oxfordjournals.org/cgi/content/short/24/23/2798 .
VignetteBuilder: knitr
License: Artistic-2.0
git_url: https://git.bioconductor.org/packages/GEOmetadb
git_branch: devel
git_last_commit: c3ec251
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 21:18:02 UTC; biocbuild
